"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
const react_1 = require("@testing-library/react");
const react_2 = __importDefault(require("react"));
const _401_9ZUI_WEB_svg_1 = __importDefault(require("../../../images/401-9ZUI-WEB.svg"));
const _403_9ZUI_WEB_svg_1 = __importDefault(require("../../../images/403-9ZUI-WEB.svg"));
const _404_WEB_svg_1 = __importDefault(require("../../../images/404-WEB.svg"));
const _500_WEB_svg_1 = __importDefault(require("../../../images/500-WEB.svg"));
const _503_WEB_svg_1 = __importDefault(require("../../../images/503-WEB.svg"));
const Generic_WEB_svg_1 = __importDefault(require("../../../images/Generic-WEB.svg"));
const Fallback_1 = require("../../containers/Fallback");
const i18n_1 = require("../../util/i18n");
const getElementsBasedOnProps = (message, translate) => {
    const { getByTestId } = react_1.render(react_2.default.createElement(Fallback_1.Fallback, { message: message, translate: translate }));
    const img = getByTestId("test-fallback-img");
    const title = getByTestId("test-fallback-title");
    const text = getByTestId("test-fallback-text");
    return { img, title, text };
};
describe("Fallback.tsx Tests", () => {
    test("Test Fallback Generic", () => {
        const { img, title, text } = getElementsBasedOnProps(undefined, true);
        expect(img.getAttribute("src")).toBe(Generic_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAltGen"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitleGen"));
        expect(text.innerHTML).toBe("");
    });
    test("Test Fallback 401", () => {
        const { img, title, text } = getElementsBasedOnProps("error401", true);
        expect(img.getAttribute("src")).toBe(_401_9ZUI_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAlt401"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitle401"));
        expect(text.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("error401"));
    });
    test("Test Fallback 403", () => {
        const { img, title, text } = getElementsBasedOnProps("error403", true);
        expect(img.getAttribute("src")).toBe(_403_9ZUI_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAlt403"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitle403"));
        expect(text.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("error403"));
    });
    test("Test Fallback 404", () => {
        const { img, title, text } = getElementsBasedOnProps("error404", true);
        expect(img.getAttribute("src")).toBe(_404_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAlt404"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitle404"));
        expect(text.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("error404"));
    });
    test("Test Fallback 500", () => {
        const { img, title, text } = getElementsBasedOnProps("error500", true);
        expect(img.getAttribute("src")).toBe(_500_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAlt500"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitle500"));
        expect(text.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("error500"));
    });
    test("Test Fallback 503", () => {
        const { img, title, text } = getElementsBasedOnProps("error503", true);
        expect(img.getAttribute("src")).toBe(_503_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAlt503"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitle503"));
        expect(text.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("error503"));
    });
    test("Test Fallback No Translate", () => {
        const { img, title, text } = getElementsBasedOnProps("No Translate", false);
        expect(img.getAttribute("src")).toBe(Generic_WEB_svg_1.default);
        expect(img.getAttribute("alt")).toBe(i18n_1.iTwinErrorI18n.t("fallbackAltGen"));
        expect(title.innerHTML).toBe(i18n_1.iTwinErrorI18n.t("fallbackTitleGen"));
        expect(text.innerHTML).toBe("No Translate");
    });
});
//# sourceMappingURL=Fallback.test.js.map